# Loducode web3

Basic components for the development of loducode s.a.s.

### install

`pip install loducode_web3==0.1.6`

## functionalities

- **Models**
    - AttributeNft
    - Nft

## Commands

- python setup.py sdist bdist_wheel
- twine upload --repository pypi dist/loducode_web3-0.1.6*

## push
git tag -a 0.1.6 -m "annotation for this release"

entrar a la carpeta loducode_web3 y correr
- django-admin makemessages
- django-admin compilemessages

#### Version 0.1.6
- update requirements loducode utils and web3
- add method create wallet

#### Version 0.1.5
- update requirements loducode utils

#### Version 0.1.4
- update requirements loducode utils

#### Version 0.1.4
- delete requirement sycopg2-binary==2.8.4

#### Version 0.1.3
- add translation

#### Version 0.1.2
- add method add_white_list

#### Version 0.1.1
- Models abstracts

#### Version 0.1.0
- Models abstracts

#### Version 0.0.1
- first version

#### Version 0.0.2
- bug imports

#### Version 0.0.1
- first version
